"use client";
import React from "react";
import { useSidebar, useThemeStore } from "@/store";
import { cn } from "@/lib/utils";
import { useMediaQuery } from "@/hooks/use-media-query";
import ModuleSidebar from "./module";
import PopoverSidebar from "./popover";
import ClassicSidebar from "./classic";
import MobileSidebar from "./mobile-sidebar";

const Sidebar = ({ userKycData, dataTheme }) => {
  const { sidebarType, collapsed,showText } = useSidebar();
  const { layout } = useThemeStore();

  const isDesktop = useMediaQuery("(min-width: 1280px)");

  let selectedSidebar = null;

  if (!isDesktop && (sidebarType === "popover" || sidebarType === "classic")) {
    selectedSidebar = <MobileSidebar />;
  } else {
    const sidebarComponents = {
      module: <ModuleSidebar collapsed={collapsed} showText={showText} userKycData={userKycData} dataTheme={dataTheme} />,
      popover: <PopoverSidebar collapsed={collapsed} showText={showText} userKycData={userKycData} dataTheme={dataTheme} />,
      classic: <ClassicSidebar userKycData={userKycData} dataTheme={dataTheme} />,
    };

    selectedSidebar = sidebarComponents[sidebarType] || <ModuleSidebar userKycData={userKycData} dataTheme={dataTheme} />;
  }

  return <div>{selectedSidebar}</div>;
};

export default Sidebar;
